package com.yiqi.core.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.core.domain.ClothWashProblem;

/**
 * 洗衣问题Mapper接口
 *
 * @author xiaohei
 * @date 2023-11-16
 */
public interface ClothWashProblemMapper extends BaseMapper<ClothWashProblem> {
    //<editor-folder desc="基础韩素">
    /**
     * 查询洗衣问题
     *
     * @param id 洗衣问题主键
     * @return 洗衣问题
     */
    public ClothWashProblem selectClothWashProblemById(Long id);

    /**
     * 查询洗衣问题列表
     *
     * @param clothWashProblem 洗衣问题
     * @return 洗衣问题集合
     */
    public List<ClothWashProblem> selectClothWashProblemList(ClothWashProblem clothWashProblem);

    /**
     * 新增洗衣问题
     *
     * @param clothWashProblem 洗衣问题
     * @return 结果
     */
    public int insertClothWashProblem(ClothWashProblem clothWashProblem);

    /**
     * 修改洗衣问题
     *
     * @param clothWashProblem 洗衣问题
     * @return 结果
     */
    public int updateClothWashProblem(ClothWashProblem clothWashProblem);

    /**
     * 删除洗衣问题
     *
     * @param id 洗衣问题主键
     * @return 结果
     */
    public int deleteClothWashProblemById(Long id);

    /**
     * 批量删除洗衣问题
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteClothWashProblemByIds(Long[] ids);
    //</editor-folder>
}
